Learn R Programming

ordinalTables (version 1.0.0.3)

Agresti_simple_diagonals_parameter_quasi_symmetry: Agresti's simple diganal quasi-symmetry model.

Description

This parameterization does not match equation (2.2) in the paper, but it yields results that are identical to those in the paper. Agresti, A. (1983), A simple diagonals-parameter symmetry and quasi-symmetry model. Statistics and Probability Letters I, 313-316.

Usage

Agresti_simple_diagonals_parameter_quasi_symmetry(n)

Value

a list containing expected: matrix of expected cell frequencies, chisq: Pearson X^2 g_squared: likelihood ratio G^2 df: degrees of freedom beta: the parameter estimated sigma_beta: standard error of beta z: z-score for beta delta: transformation of the the parameter into the model formulation

Arguments

n

the matrix of observed counts

Examples

Run this code
Agresti_simple_diagonals_parameter_quasi_symmetry(vision_data)

Run the code above in your browser using DataLab