Learn R Programming

ordinalTables (version 1.0.0.3)

Clayton_stratified_marginal_location: Clayton's stratified version of the marginal location comparison.

Description

Compares marginal location conditional on a stratifying variable. Clayton, D. G. (1974) Odds ratio statistics for the analysis of ordered categorical data. Biometrika, 61(3), 525-531.

Usage

Clayton_stratified_marginal_location(mx, my)

Value

a list of results odds_ratios: odds ratios comparing cumulative frequencies of adjacent categories log_theta_hat: log of estimate of the common odds-ratio theta_hat: estimate of the common odds-ratio log_mh_theta_hat: log of the Mantel-Haenssel type odds-ratio mh_theta_hat: Mantel-Haenszel type odds-ratio var_log_theta_hat = variance of the log of the odds-ratios chisq_theta_hat: chi-square for odds-ratio chisq_mh_theta_hat: chi-square for Mantel-Haenszel odds-ratio df: degrees of freedom for chis-square = 1

Arguments

mx

matrix with

my

matrix with

See Also

[Clayton_marginal_location()]