Learn R Programming

ordinalTables (version 1.0.0.3)

Cliff_as_d_matrix: Converts two vectors containing scores and integer frequencies (cell counts) into a d-matrix

Description

Converts two vectors containing scores and integer frequencies (cell counts) into a d-matrix

Usage

Cliff_as_d_matrix(scores, cells, nrow = NULL)

Value

d-matrix of results

Arguments

scores

vector of scores, typically 1:r

cells

vector of integer weights, i.e. cell frequencies

nrow

number of score categories in table. Default is NULL. If NULL, takes 1:length(scores)