Learn R Programming

ordinalTables (version 1.0.0.3)

Cliff_dependent_compute_paired_d: Computes Cliff's dependent d-statistics based on cell frequencies.

Description

Computes d-matrix and then analyzes it. This can be time consuming. Try Cliff_dependent_from_table() instead. The current function is provided mainly for comparison & validation. For an example, compare running this function on vision_data to running Cliff_dependent_from_table(vision_data).

Usage

Cliff_dependent_compute_paired_d(cells)

Value

a list containing dw: within-subjects d-statistic sigma_dw: SE of dw z_dw: z-score for dw db: between-subjects d-statistic sigma_db: SE of db z_db: z-score for db db_dw: sum db + dw, omnibus measure sigma_db_dw: SE of db + dw z_db_dw: z-score of db _ dw cov_db_dw: covariance between db and dw

Arguments

cells

r x r matrix of frequencies

Details

dw - within-subjects d-statistic db - between-subjects d-statistic db_dw - sum of dw and db, omnibus test of whether one group is higher than the other Cliff, N. (1993). Dominance statistics: Ordinal analyses to answer ordinal questions. Psychological Bulletin, 114(3), 494-509. Cliff, N. (1996). Ordinal methods for behavioral data analysis. Mawhaw NJ: Lawerence-Erlbaum.

See Also

[Cliff_dependent_compute_from_table()]

Examples

Run this code
Cliff_dependent_compute_paired_d(movies)

Run the code above in your browser using DataLab