Learn R Programming

ordinalTables (version 1.0.0.3)

Goodman_constrained_diagonals_parameter_symmetry: Fits the model where some of the delta parameters are constrained to be equal to one another.

Description

Fits the model where some of the delta parameters are constrained to be equal to one another.

Usage

Goodman_constrained_diagonals_parameter_symmetry(n, equality)

Value

a list containing pooled_chisq: Pearson chi-square for the pooled delta values pooled_df: degrees of freedom for pooled chisq omnibus_chisq: Pearson chi-square for overall model fit, subject to equality constraints omnibus_df; degrees of freedom for omnibus_chisq equality_chisq: Pearson chi-square for test that remaining deltas are all equal equality_df: degrees of freedom for equality_chisq delta_pooled: estimate of pooled delta

Arguments

n

the matrix of observed counts

equality

logical vector indicating whether corresponding delta the parameter is part of the equality set.

Examples

Run this code
equality = c(TRUE, TRUE, FALSE)
Goodman_diagonals_parameter_symmetry(vision_data)

Run the code above in your browser using DataLab