Learn R Programming

ordinalTables (version 1.0.0.3)

Goodman_diagonals_parameter_symmetry: Fit's Goodman's diagonals parameter symmetry model.

Description

Goodman, L. A. (1979). Multiplicative models for square contingency tables with ordered categories. Biometrika, 66(3), 413-316.

Usage

Goodman_diagonals_parameter_symmetry(n)

Value

a list containing individual_chisq: chi-square value for each diagonal individual_df: degrees of freedom for individual_chisq omnibus_chisq: overall chi-square for the model omnibus_df: degrees for freedom for omnibus_chisq equality_chisq: chi-square for test that all delta values are equal equality_df: degrees of freedom from equality_chisq delta: the vector of estimated delta values (without any equality constraints)

Arguments

n

the matrix of obsever counts

Examples

Run this code
Goodman_diagonals_parameter_symmetry(vision_data)

Run the code above in your browser using DataLab