Learn R Programming

ordinalTables (version 1.0.0.3)

Goodman_null_association: Fits Goodman's L. A. (1979) Simple Models for the Analysis of Association in Cross-Classifications Having Ordered Categories

Description

null association model

Usage

Goodman_null_association(
  n,
  max_iter = 25,
  verbose = FALSE,
  exclude_diagonal = FALSE
)

Value

a list containing alpha: row effects beta: column effects log_likelihood: log(likelihood) g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom

Arguments

n

matrix of observed counts

max_iter

maximum number of iterations. Default is 10

verbose

should cycle-by-cycle info be printed? Default is FALSE

exclude_diagonal

logical, Should the diagonal be excluded from the computations. Default is FALSE