Learn R Programming

ordinalTables (version 1.0.0.3)

Goodman_symmetric_association_model: Fits the symmetric association model from Goodman (1979). Note the model is a reparameterized version of the quasi-symmetry model, so the quasi-symmetry model has the same fit indices.

Description

Fits the symmetric association model from Goodman (1979). Note the model is a reparameterized version of the quasi-symmetry model, so the quasi-symmetry model has the same fit indices.

Usage

Goodman_symmetric_association_model(n)

Value

a list containing x: design matrix used for the glm() regression beta: parameter estimates se: standard errors of beta g_squared: G^2 measure of fit chisq: X^2 measure of fit df: degrees of freedom expected: model-based expected cell counts

Arguments

n

matrix of observed counts