Learn R Programming

ordinalTables (version 1.0.0.3)

McCullagh_compute_condition: Compute the linear constraint on psi elements for identifiablity.

Description

Compute the linear constraint on psi elements for identifiablity.

Usage

McCullagh_compute_condition(psi)

Value

value of the constraint

Arguments

psi

symmetry matrix