Learn R Programming

ordinalTables (version 1.0.0.3)

McCullagh_get_statistics: Computes summary statistics needed to compute estimate of delta.

Description

Computes summary statistics needed to compute estimate of delta.

Usage

McCullagh_get_statistics(m)

Value

a list containing: N: matrix of sums above and below the diagonal n: vector, size of binomial r: vector, observed sums, number of successes for binomail

Arguments

m

matrix of observed counts