Learn R Programming

ordinalTables (version 1.0.0.3)

McCullagh_is_in_constraint_set: Logical test of whether a specific psi will be in the constraint set.

Description

Logical test of whether a specific psi will be in the constraint set.

Usage

McCullagh_is_in_constraint_set(i, j)

Value

TRUE if it falls within the set, FALSE otherwise.

Arguments

i

first index of psi

j

second index of psi