McCullah, P. (1977). A logistic model for paired comparisons with ordered categorical data.
Biometrika, 64(3), 449-453.
Usage
McCullagh_logistic_model(m)
Value
a list containing
w_tilde: vector of model weights for sum of normally distributed components
delta_tilde: delta parameter computed using w_tilde
w_star: vector of weights for Mantel-Haenszel type numerator and denominator
delta_star: delta parameter computed using w_star
var: variance of delta estimate