Learn R Programming

ordinalTables (version 1.0.0.3)

McCullagh_palindromic_symmetry: McCullagh's palindromic symmetry model

Description

McCullagh, P. (1978). A class of parametric models for the analysis of square contingency tables with ordered categories. Biometrika, 65(2). 413-416.

Usage

McCullagh_palindromic_symmetry(n, max_iter = 15, verbose = FALSE)

Value

a list containing delta: the value of the asymmetry parameter delta sigma_delta: SE(delta) logL: value of log(likelihood) for final estimates chisq: Pearson chi-square for solution df: degrees of freedom for solution chisq psi: matrix of symmetry parameters alpha: c: constraint, sum of pi - values condition: constraint on psi to make model identified, Lagrange multiplier SE: vector of standard errors for all parameters

Arguments

n

matrix of observed counts

max_iter

maximum number of iterations to maximize the log(likelihood)

verbose

should cycle-by-cycle info be printed out? Default is FALSE, don't print.

Examples

Run this code
McCullagh_palindromic_symmetry(vision_data)

Run the code above in your browser using DataLab