Learn R Programming

ordinalTables (version 1.0.0.3)

McCullagh_penalized: Computes the penalized value of a derivative by adding the derivative of the penalty to it.

Description

Computes the penalized value of a derivative by adding the derivative of the penalty to it.

Usage

McCullagh_penalized(derivative, i1, j1, n, psi, delta, alpha, c = 1)

Value

derivative

Arguments

derivative

the base derivative

i1

first index of psi

j1

second index of psi

n

matrix of observed counts

psi

matrix of symmetry parameters

delta

scalar asymmetry parameter

alpha

vector of asymmetry parameters

c

normalizing factor to make pi sum to 1.0. Default is 1.0.