Learn R Programming

ordinalTables (version 1.0.0.3)

Schuster_enforce_constraints_on_v: Compute v matrix subject to constraints on rows 1..r-1.

Description

Compute v matrix subject to constraints on rows 1..r-1.

Usage

Schuster_enforce_constraints_on_v(marginal_pi, kappa, v)

Value

new v matrix with last row/column set to agree with constraints. Element v[r, r] is set to v-tilde

Arguments

marginal_pi

expected proportions for each category

kappa

current estimate of kappa coefficient

v

symmetry matrix