Learn R Programming

ordinalTables (version 1.0.0.3)

Schuster_newton_raphson: Performs Newton-Raphson step.

Description

The step size is determined to be the largest that yields valid results for all quantities marginal_pi and v. Both must be positive, and the elements of marginal_pi must be valid proportions that sum to 1.0.

Usage

Schuster_newton_raphson(n, marginal_pi, kappa, v)

Value

a list containing updated versions of model quantities marginal_pi kappa v

Arguments

n

matrix of observed counts

marginal_pi

expected proportions for each category

kappa

current estimate of the kappa coefficient

v

symmetry matrix