Learn R Programming

ordinalTables (version 1.0.0.3)

Schuster_solve_for_v1: Solves for the last row and diagonal of symmetry matrix v (parameteer v-tilde) using linear algebra formulation from paper.

Description

Solves for the last row and diagonal of symmetry matrix v (parameteer v-tilde) using linear algebra formulation from paper.

Usage

Schuster_solve_for_v1(marginal_pi, kappa, v)

Value

revised version of v matrix with last row and diagonal modified

Arguments

marginal_pi

expected proportions for each category

kappa

current estimate of kappa coefficient

v

symmetry matrix