Learn R Programming

ordinalTables (version 1.0.0.3)

Schuster_symmetric_rater_agreement_model: Computes the model that has kappa as a coefficient and symmetry.

Description

Schuster, C. (2001). Kappa as a parameter of a symmetry model for rater agreement. Journal of Educational and Behavioral Statistics, 26(3), 331-342.

Usage

Schuster_symmetric_rater_agreement_model(
  n,
  verbose = FALSE,
  max_iter = 10000,
  criterion = 1e-07,
  min_iter = 1000
)

Value

a list containing marginal_pi: vector of expected proportions for each category kappa numeric: kappa coefficient v: matrix of symmetry parameters chisq: Pearson X^2 g_squared: likelihood ratio G^2 df: degrees of freedom

Arguments

n

the matrix of observed counts

verbose

logical. should cycle-by-cycle information be printed out

max_iter

integer. maximum number of iterations to perform

criterion

number. maximum change in log(likelihood) to decide convergence

min_iter

integer. minimum number of iterations to perform