Learn R Programming

ordinalTables (version 1.0.0.3)

budget_expected: Ratings of expected participation in household budgeting by psychiatric patients. Rows are ratings by patient, columns are ratings by relative. 1 - not at all 2 - doing some 3 - doing regularly

Description

Ratings of expected participation in household budgeting by psychiatric patients. Rows are ratings by patient, columns are ratings by relative. 1 - not at all 2 - doing some 3 - doing regularly

Usage

budget_expected

Arguments

Format

## `budget_expected` a matrix with 3 rows and 3 columns.