Learn R Programming

ordinalTables (version 1.0.0.3)

coal_g: Degree of disease measured at two points in time for mine workers.

Description

Based on radiological measurements, the matrix contains the degree of pneumoconiosis in coal workers. 1 = least severe disease and 4 = most severe.

Usage

coal_g

Arguments

Format

## `coal_g` A matrix with 4 rows and 4 columns.