Learn R Programming

ordinalTables (version 1.0.0.3)

dogs: Dehydration in dogs data set.

Description

An interrater agreement data set from Shourki, M. M. (2005, p.80). It is agreement study of two clinicians evaluating whether dogs were dehydrated. The lowest score indicates normal, and the highest score indicates dehydrated (above 10 The "g" in the name indicates that this is taken from mine "G" in the original study.

Usage

dogs

Arguments

Format

## `dogs` A matrix with 4 rows and 4 columns.