Learn R Programming

ordinalTables (version 1.0.0.3)

dreams: Severity of disturbing dreams in adolescent boys, measured at two ages..

Description

Severity of disturbing dreams in adolescent boys, measured at two ages..

Usage

dreams

Arguments

Format

## `dreams` A matrix with 4 rows and 4 columns.