Learn R Programming

ordinalTables (version 1.0.0.3)

esophageal_cancer: Ratings of number of hot drinks consumed by cases with cancer of the esophagus, compared with control subjects.

Description

Ratings of number of hot drinks consumed by cases with cancer of the esophagus, compared with control subjects.

Usage

esophageal_cancer

Arguments

Format

## `esophageal_cancer` A matrix with 4 rows and 4 columns.