Learn R Programming

ordinalTables (version 1.0.0.3)

log_Linear_create_log_n: Computes the logs of the cell frequencies.

Description

In the case of an observed 0, epsilon is inserted into the cell before the log is taken.

Usage

log_Linear_create_log_n(n, epsilon = 1e-06, all_cells = FALSE)

Value

a list containing: log_n -- a vector of log frequencies and dat -- modified version of the cell counts data

Arguments

n

matrix of cell counts

epsilon

amount to be inserted into cell with observed 0.

all_cells

add epsilon to all cells or just those with 0 observed frequencies