Learn R Programming

ordinalTables (version 1.0.0.3)

log_linear_equal_weight_agreement_design: Creates design matrix for model with main effects and a single agreement parameter delta.

Description

The model has main effects for rows and for columns, plus an additional parameter for the agreement (diagonal) cells.

Usage

log_linear_equal_weight_agreement_design(n, n_raters = 2)

Value

design matrix for the model

Arguments

n

the matrix of cell counts

n_raters

number of raters. Currently only 2 (the default) are supported. This is an extension point for future work.

Examples

Run this code
x <- log_linear_equal_weight_agreement_design(vision_data)

Run the code above in your browser using DataLab