Learn R Programming

ordinalTables (version 1.0.0.3)

log_linear_matrix_to_vector: Converts a matrix of data into a vector suitable for use in analysis with the design matrices created. Unlike simply calling vector() on the matrix the resulting vector is organized by rows, then columns. This order corresponds to the order in the design matrix.

Description

Converts a matrix of data into a vector suitable for use in analysis with the design matrices created. Unlike simply calling vector() on the matrix the resulting vector is organized by rows, then columns. This order corresponds to the order in the design matrix.

Usage

log_linear_matrix_to_vector(dat)

Value

a vector suitable to use as dependent variable, e.g. in a call to glm()

Arguments

dat

the matrix to be converted a vector