Learn R Programming

ordinalTables (version 1.0.0.3)

model_i_update_alpha: Updates the estimate of the alpha vector for Model I

Description

Updates the estimate of the alpha vector for Model I

Usage

model_i_update_alpha(alpha, n, fHat, exclude_diagonal = FALSE)

Value

updated estimate of alpha vector

Arguments

alpha

current estimate of beta

n

matrix of observed counts

fHat

current model-based counts for each cell

exclude_diagonal

logical. Should the diagonal be excluded from the computation? Default is FALSE, use all cells.