Learn R Programming

ordinalTables (version 1.0.0.3)

model_i_update_gamma: Updates the estimate of the gamma vector for Model I

Description

Updates the estimate of the gamma vector for Model I

Usage

model_i_update_gamma(gamma, n, fHat, exclude_diagonal = FALSE)

Value

updated estimate of gamma vector

Arguments

gamma

current estimate of gamma

n

matrix of observed counts

fHat

current model-based counts for each cell

exclude_diagonal

logical. Should the diagonal be excluded from the computation? Default is FALSE, use all cells