Learn R Programming

ordinalTables (version 1.0.0.3)

model_i_zeta: Computes the overall association theta and the row and column effects zeta

Description

Computes the overall association theta and the row and column effects zeta

Usage

model_i_zeta(odds)

Value

a list containing theta: the overall association zeta_i_dot: row effects for association zeta_dot_j: column effects for association

Arguments

odds

matrix of adjacent odds-ratios