Learn R Programming

ordinalTables (version 1.0.0.3)

model_ii_update_alpha: Updates the estimate of the alpha vector for Model II

Description

Updates the estimate of the alpha vector for Model II

Usage

model_ii_update_alpha(alpha, n, fHat, exclude_diagonal = FALSE)

Value

updated estimate of alpha vector

Arguments

alpha

current estimate of alpha

n

matrix of observed counts

fHat

current model-based counts for each cell

exclude_diagonal

logical, Should the cells on the main diagonal be excluded? Default is FALSE, use all cells