Learn R Programming

ordinalTables (version 1.0.0.3)

model_ii_update_beta: Updates the estimate of the beta vector for Model II

Description

Updates the estimate of the beta vector for Model II

Usage

model_ii_update_beta(beta, n, fHat, exclude_diagonal = FALSE)

Value

updated estimate of beta vector

Arguments

beta

current estimate of beta

n

matrix of observed counts

fHat

current model-based counts for each cell

exclude_diagonal

logical, Should the cells on the main diagonal be excluded? Default is FALSE, use all cells