Learn R Programming

ordinalTables (version 1.0.0.3)

model_ii_update_rho: Updates the estimate of the rho vector for Model II

Description

Updates the estimate of the rho vector for Model II

Usage

model_ii_update_rho(n, fHat, mu, sigma, exclude_diagonal = FALSE)

Value

updated estimate of alpha vector

Arguments

n

matrix of observed counts

fHat

current model-based counts for each cell

mu

alternative row coefficients

sigma

vector of column location parameters

exclude_diagonal

logical, Should the cells on the main diagonal be excluded? Default is FALSE, use all cells