Learn R Programming

ordinalTables (version 1.0.0.3)

movies: Movie ratings by two film critics, Siskel and Ebert.

Description

Movie ratings by two film critics, Siskel and Ebert.

Usage

movies

Arguments

Format

## `movies` A matrix with 3 rows and 3 columns 1 is con 2 is mixed 3 is pro