Learn R Programming

ordinalTables (version 1.0.0.3)

new_orleans_data: Agreement between two clinicians on presence of multiple sclerosis based on file.

Description

See companion winnipeg_data.

Usage

new_orleans_data

Arguments

Format

## `new_orleans_data` A matrix with 4 rows and 4 columns Ratings range from definite presence of disease to definite absence.