Learn R Programming

ordinalTables (version 1.0.0.3)

uniform_association_update_theta: Updates estimate of theta value of the uniform association model

Description

Updates estimate of theta value of the uniform association model

Usage

uniform_association_update_theta(theta, n, fHat, exclude_diagonal = FALSE)

Value

updated estimate of theta parameter

Arguments

theta

current estimate of theta

n

matrix of observed counts

fHat

current model-based counts for each cell

exclude_diagonal

logical. Should the cells of the main diagonal be excluded from the computations? Defualt is FALSE, include all cells.