Learn R Programming

ordinalTables (version 1.0.0.3)

var_kappa: Computes the sampling variance of kappa.

Description

Formulas are from the paper by Fleiss,J. L., Cohen, J., & Everitt, B. S. (1969). Large sample standard errors of kappa and weighted kappa. Two results are returned in a list. var_kappa0 is the null case and would be used for testing the hypothesis that kappa = 0. The second is var_kappa and is for the non-null case, such as constructing CI for estimated kappa. Not that both are in the variance metric. Take the square root to get the standard error.

Usage

var_kappa(n)

Value

a list containing; var_kappa0: variance for the null case var_kappa: variance for the non-null case.

Arguments

n

matrix of observe counts