von_Eye_diagonal: Fits the diagonal effects model, where each category has its own parameter delta[k].
Description
Fits the diagonal effects model, where each category has its own parameter delta[k].
Usage
von_Eye_diagonal(n)
Value
a list containing
beta: the regression parameters. delta parameters are the final elements of beta
g_squared: G^2 fit measure
chisq: X^2 fit measure
df: degrees of freedom
expected: matrix of expected frequencies