Learn R Programming

ordinalTables (version 1.0.0.3)

von_Eye_equal_weight_diagonal_linear: Fits the diagonal effects model, where there is a single delta parameter for all categories, while also incorporating a linear-by-linear term.

Description

Fits the diagonal effects model, where there is a single delta parameter for all categories, while also incorporating a linear-by-linear term.

Usage

von_Eye_equal_weight_diagonal_linear(n, center = TRUE)

Value

a list containing beta: the regression parameters. delta parameters come after rows and columns and finally the linear-by-linear term g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom expected: matrix of expected frequencies

Arguments

n

the matrix of observed counts

center

should the linear-by-linear components be centered to have mean 0? Default is TRUE