Learn R Programming

ordinalTables (version 1.0.0.3)

von_Eye_equal_weighted_diagonal: Fits the equal weighted diagonal model, where the diagonals all have an additional parameter delta, with the constraint that delta is equal across all categories.

Description

Fits the equal weighted diagonal model, where the diagonals all have an additional parameter delta, with the constraint that delta is equal across all categories.

Usage

von_Eye_equal_weighted_diagonal(n)

Value

a list containing beta: the regression parameters g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom expected: matrix of expected frequencies

Arguments

n

the matrix of observed counts