Learn R Programming

ordinalTables (version 1.0.0.3)

von_Eye_linear_by_linear: Fits the basic independent rows and columns model incorporating a linear-by-linear term.

Description

Fits the basic independent rows and columns model incorporating a linear-by-linear term.

Usage

von_Eye_linear_by_linear(n, center = TRUE)

Value

a list containing beta: the regression parameters. The linear-by-linear parameter is last g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom expected: matrix of expected frequencies

Arguments

n

matrix of observed counts

center

should the linear-by-linear components be centered to have mean 0? Default is TRUE