Learn R Programming

ordinalTables (version 1.0.0.3)

von_Eye_main_effect: Fits the base model with only independent row and column effects.

Description

Fits the base model with only independent row and column effects.

Usage

von_Eye_main_effect(n)

Value

a list containing beta: the regression parameters g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom expected: matrix of expected frequencies

Arguments

n

the matrix of observed counts