Learn R Programming

ordinalTables (version 1.0.0.3)

winnipeg_data: Agreement between two clinicians on presence of multiple sclerosis based on file.

Description

See companion new_orleans_data.

Usage

winnipeg_data

Arguments

Format

## `winnipeg_data` A matrix with 4 rows and 4 columns Ratings range from definite presence of disease to definite absence.