This parameterization does not match equation (2.2) in the paper, but it yields results that are identical to those in the paper. Agresti, A. (1983), A simple diagonals-parameter symmetry and quasi-symmetry model. Statistics and Probability Letters I, 313-316.
Agresti_create_design_matrix(n_dim)the design matrix for the model, that can bee used with ml_for_log_linear
the size of the date matrix