a list containing
pooled_chisq: Pearson chi-square for the pooled delta values
pooled_df: degrees of freedom for pooled chisq
omnibus_chisq: Pearson chi-square for overall model fit, subject to equality constraints
omnibus_df; degrees of freedom for omnibus_chisq
equality_chisq: Pearson chi-square for test that remaining deltas are all equal
equality_df: degrees of freedom for equality_chisq
delta_pooled: estimate of pooled delta
Arguments
n
the matrix of observed counts
equality
logical vector indicating whether corresponding delta the parameter is part
of the equality set.