The model has simple closed form solutions when fitting either the unconstrained
version of the version that species equality of delta parameters. However,
I could not see how to adapt that to the case where specific parameters were
constrained to have a specific value. This routine is to fit that model. It will
also fit the unconstrained model, but Goodman gives the estimator for that case.
Usage
Goodman_ml(n, phi, delta, fixed)
Value
list containing new estimates of phi amd delta
Arguments
n
the r X r matrix of observed counts
phi
the symmetric matrix parameter
delta
the vector of asymmetry r - 1 parameters
fixed
r - 1 logical vector that specifies whether a delta parameter is fixed
(TRUE) or allowed to be estimated (FALSE).