McCullagh_compute_omega: Compute the value of the Lagrange multiplier for the constraint on psi.
Description
Compute the value of the Lagrange multiplier for the constraint on psi.
Usage
McCullagh_compute_omega(n, pi)
Value
the value of the Lagrange multiplier.
Arguments
- n
matrix of observed counts
- pi
matrix of model-based probabilities pi.