McCullagh_compute_pi_from_beta: Computes matrix of p-values pi based on x and current value of beta.
Description
Computes matrix of p-values pi based on x and current value of beta.
Usage
McCullagh_compute_pi_from_beta(n, x, beta)
Value
matrix of model-based pi values
Arguments
- n
matrix of observed counts
- x
design matrix
- beta
current values of location model regression parameters