Using gradient and hessian, it finds the update direction. Then it tries increassingly smaller step sizes until the step*update yields a valid pi matrix.
McCullagh_newton_raphson_update(
n,
gradient,
hessian,
psi,
delta,
alpha,
c = 1,
max_iter = 50,
verbose = FALSE
)list containing new parameters psi: matrix of symmetry parameters delta; scalar or vector of asymmetry parameters alpha: vector of asymmetry parameters c: scaling coefficient to ensure pi sums to 1.0
matrix of observed counts
gradient vector
hessian matrix
matrix of symmetry parameters
scalar or vector of asymmetry parameters
vector of asymmetry parameters
scaling factor to ensure pi sums to 1.0. Default is 1.0
maximum number of iterations. Default is 50.
should cycle-by-cycle into be printed out. Default is FALSE, do not print.