The step size is determined to be the largest that yields valid results for all quantities marginal_pi and v. Both must be positive, and the elements of marginal_pi must be valid proportions that sum to 1.0.
Schuster_newton_raphson(n, marginal_pi, kappa, v)a list containing updated versions of model quantities marginal_pi kappa v
matrix of observed counts
expected proportions for each category
current estimate of the kappa coefficient
symmetry matrix