Solves for the last row and diagonal of symmetry matrix v (parameteer v-tilde) using linear algebra formulation from paper.
Schuster_solve_for_v1(marginal_pi, kappa, v)revised version of v matrix with last row and diagonal modified
expected proportions for each category
current estimate of kappa coefficient
symmetry matrix