Schuster, C. (2001). Kappa as a parameter of a symmetry model for rater agreement. Journal of Educational and Behavioral Statistics, 26(3), 331-342.
Schuster_symmetric_rater_agreement_model(
n,
verbose = FALSE,
max_iter = 10000,
criterion = 1e-07,
min_iter = 1000
)a list containing marginal_pi: vector of expected proportions for each category kappa numeric: kappa coefficient v: matrix of symmetry parameters chisq: Pearson X^2 g_squared: likelihood ratio G^2 df: degrees of freedom
the matrix of observed counts
logical. should cycle-by-cycle information be printed out
integer. maximum number of iterations to perform
number. maximum change in log(likelihood) to decide convergence
integer. minimum number of iterations to perform