budget_actual: Participation in household budgeting by psychiatric patients.
Rows are ratings by patient, columns are ratings by relative.
1 - not at all
2 - doing some
3 - doing regularly
Description
Participation in household budgeting by psychiatric patients.
Rows are ratings by patient, columns are ratings by relative.
1 - not at all
2 - doing some
3 - doing regularly
Usage
budget_actual
Arguments
Format
## `budget_actual`
A matrix with 3 rows and 3 columns