constant_of_integration: Computes the constant of integration of a multinomial sample.
Description
N! / product(n[i]!)
Usage
constant_of_integration(n, exclude_diagonal = FALSE)
Value
value of constant of integration for observed matrix provided
Arguments
- n
Matrix of observed counts
- exclude_diagonal
logical. Should the diagonal cells of a
square matrix be excluded from the computation. Default is FALSE,