In the case of an observed 0, epsilon is inserted into the cell before the log is taken.
log_Linear_create_log_n(n, epsilon = 1e-06, all_cells = FALSE)a list containing: log_n -- a vector of log frequencies and dat -- modified version of the cell counts data
matrix of cell counts
amount to be inserted into cell with observed 0.
add epsilon to all cells or just those with 0 observed frequencies