powered by
The model has main effects for rows and for columns, plus an additional parameter for the agreement (diagonal) cells.
log_linear_equal_weight_agreement_design(n, n_raters = 2)
design matrix for the model
the matrix of cell counts
number of raters. Currently only 2 (the default) are supported. This is an extension point for future work.
x <- log_linear_equal_weight_agreement_design(vision_data)
Run the code above in your browser using DataLab