model_i_update_beta: Updates the estimate of the beta vector for Model I
Description
Updates the estimate of the beta vector for Model I
Usage
model_i_update_beta(beta, n, fHat, exclude_diagonal = FALSE)
Value
updated estimate of beta vector
Arguments
- beta
current estimate of alpha
- n
matrix of observed counts
- fHat
current model-based counts for each cell
- exclude_diagonal
logical. Should the diagonal be excluded
from the computation? Default is FALSE, use all cells