model_ii_update_sigma: Updates the estimate of the sigma vector for Model II
Description
Updates the estimate of the sigma vector for Model II
Usage
model_ii_update_sigma(n, fHat, nu, rho, exclude_diagonal = FALSE)
Value
updated estimate of sigma vector
Arguments
- n
matrix of observed counts
- fHat
current model-based counts for each cell
- nu
vector of column coefficients
- rho
vector of row location parameters
- exclude_diagonal
logical, Should the cells on the main diagonal be
excluded? Default is FALSE, use all cells