Updates estimate of theta value of the uniform association model
uniform_association_update_theta(theta, n, fHat, exclude_diagonal = FALSE)updated estimate of theta parameter
current estimate of theta
matrix of observed counts
current model-based counts for each cell
logical. Should the cells of the main diagonal be excluded from the computations? Defualt is FALSE, include all cells.