Fits the diagonal effects model, where there is a single delta parameter for all categories, while also incorporating a linear-by-linear term.
von_Eye_equal_weight_diagonal_linear(n, center = TRUE)a list containing beta: the regression parameters. delta parameters come after rows and columns and finally the linear-by-linear term g_squared: G^2 fit measure chisq: X^2 fit measure df: degrees of freedom expected: matrix of expected frequencies
the matrix of observed counts
should the linear-by-linear components be centered to have mean 0? Default is TRUE